@@ -23,7 +23,9 @@ class BaseFunctions(SalureConnect):
         credentials = self.get_system_credential(system='sap', label=label)
         self.label = label
         self.credentials = credentials
+        self.certificate_file = certificate_file
         self.key_file = key_file
+        self.client_secret = client_secret
         self.base_url = credentials['base_url']
         self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], certificate_file, key_file, credentials['client_secret'])
         self.data_dir = data_dir
@@ -126,7 +128,15 @@ class BaseFunctions(SalureConnect):
                 doc = etree.XML(response.content)
                 error_code = doc.getchildren()[0].text
                 error_message = doc.getchildren()[1].text
-                raise ConnectionError(f'Error from SAP while calling endpoint {uri}. The message is \"{error_message}\" with code {error_code}')
+                try:
+                    error_details = doc.getchildren()[2].getchildren()[4].getchildren()[0].getchildren()[1].text
+                    error_details_status = doc.getchildren()[2].getchildren()[4].getchildren()[0].getchildren()[3].text
+                    error_details_status = "" if error_details_status is None else f"\r\nReal Status: {error_details_status}\r\n"
+                except Exception:
+                    error_details = ""
+                    error_details_status = ""
+                raise ConnectionError(
+                    f'Error from SAP while calling endpoint {uri}. \r\nThe message is \"{error_message}\" with code {error_code}, \r\nDetails: {error_details}{error_details_status}')
             else:
                 raise ConnectionError(f'Error from SAP while calling endpoint {uri}. There is no message with code {response.status_code}')
 
